==> lori_sdk-0.7.3.tar.gz: lib/data/models/userAddress.dart <==
import 'package:json_annotation/json_annotation.dart';

part 'userAddress.g.dart';

@JsonSerializable()
class UserAddress {
  UserAddress();

  String id;
  String label;

  @JsonKey(name: 'cep')
  String rawCep;

  @JsonKey(ignore: true)
  String get cep {
    return this.rawCep ?? this.zipCode;
  }
  void set cep(String cep) {
    this.rawCep = cep;
  }

  String zipCode;
  String street = '';
  String neighborhood = '';
  String number = '';
  String complement = '';
  String city = '';
  String state = '';
  String reference = '';
  bool isPrimary;
  double latitude;
  double longitude;
  bool isDeleted;

  String lineOne() {
    return _concatFields([street, number, complement, cep, reference]);

//    var lineMembers = [street, number, complement, cep, landmark];
//    var lineOne = '';
//    for (var member in lineMembers) {
//      if (member != null && member != '-' && member != '') {
//        if (lineOne != '') lineOne += ', ';
//        lineOne += member;
//      }
//    }
//    return lineOne;
  }

  String lineTwo() {
    return _concatFields([neighborhood, city, state]);

//    var lineMembers = [neighborhood, city, state];
//    var lineTwo = '';
//    for (var member in lineMembers) {
//      if (member != null && member != '-' && member != '') {
//        if (lineTwo != '') lineTwo += ', ';
//        lineTwo += member;
//      }
//    }
//    return lineTwo;
  }

  String full() {
    var firstLine = lineOne();
    var secondLine = lineTwo();
    if (firstLine.isEmpty)
      return secondLine;
    else
      return firstLine + " | " + secondLine;
  }
  
  String get streetNumber {
    return _concatFields([street, number]);
  }

  String get cityState {
    return "${city != null ? "$city - " : ''}${state ?? ''}";
  }
  
  String get checkoutAddress {
    return _concatFields([streetNumber, neighborhood, cityState, cep]);
  }

  String _concatFields(List<String> fields) {
    var concat = '';
    for (var member in fields) {
      if (member != null && member != '-' && member != '') {
        if (concat != '') concat += ', ';
        concat += member;
      }
    }
    return concat;
  }

  factory UserAddress.fromJson(Map<String, dynamic> json) =>
      _$UserAddressFromJson(json);

  Map<String, dynamic> toJson() => _$UserAddressToJson(this);
}

==> lori_sdk-0.9.2.tar.gz: lib/data/models/userAddress.dart <==
part 'userAddress.g.dart';

class UserAddress {
  UserAddress();

  String id;
  String label;

  String rawCep;

  String get cep {
    return this.rawCep ?? this.zipCode;
  }

  set cep(String cep) {
    this.rawCep = cep;
  }

  String zipCode;
  String street = '';
  String neighborhood = '';
  String number = '';
  String complement = '';
  String city = '';
  String state = '';
  String reference = '';
  bool isPrimary;
  double latitude;
  double longitude;
  bool isDeleted;

  String lineOne() {
    return _concatFields([street, number, complement, cep, reference]);

//    var lineMembers = [street, number, complement, cep, landmark];
//    var lineOne = '';
//    for (var member in lineMembers) {
//      if (member != null && member != '-' && member != '') {
//        if (lineOne != '') lineOne += ', ';
//        lineOne += member;
//      }
//    }
//    return lineOne;
  }

  String lineTwo() {
    return _concatFields([neighborhood, city, state]);

//    var lineMembers = [neighborhood, city, state];
//    var lineTwo = '';
//    for (var member in lineMembers) {
//      if (member != null && member != '-' && member != '') {
//        if (lineTwo != '') lineTwo += ', ';
//        lineTwo += member;
//      }
//    }
//    return lineTwo;
  }

  String full() {
    var firstLine = lineOne();
    var secondLine = lineTwo();
    if (firstLine.isEmpty)
      return secondLine;
    else
      return firstLine + " | " + secondLine;
  }

  String get streetNumber {
    return _concatFields([street, number]);
  }

  String get cityState {
    return "${city != null ? "$city - " : ''}${state ?? ''}";
  }

  String get checkoutAddress {
    return _concatFields([streetNumber, neighborhood, cityState, cep]);
  }

  String _concatFields(List<String> fields) {
    var concat = '';
    for (var member in fields) {
      if (member != null && member != '-' && member != '') {
        if (concat != '') concat += ', ';
        concat += member;
      }
    }
    return concat;
  }

  factory UserAddress.fromJson(Map<String, dynamic> json) =>
      _$UserAddressFromJson(json);

  Map<String, dynamic> toJson() => _$UserAddressToJson(this);
}
